@@ -2,7 +2,7 @@ Sys.setlocale("LC_COLLATE", "C") ## What CRAN does
 set.seed(999)
 options(warn=1)
 
-public({
+httptest::public({
     cacheKeys <- httpcache:::cacheKeys
     content <- httr::content
 })
